# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class QueueConversationMessageEventTopicMessageMediaParticipant(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        QueueConversationMessageEventTopicMessageMediaParticipant - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'address': 'str',
            'start_time': 'datetime',
            'connected_time': 'datetime',
            'end_time': 'datetime',
            'start_hold_time': 'datetime',
            'purpose': 'str',
            'state': 'str',
            'direction': 'str',
            'disconnect_type': 'str',
            'held': 'bool',
            'wrapup_required': 'bool',
            'wrapup_prompt': 'str',
            'user': 'QueueConversationMessageEventTopicUriReference',
            'queue': 'QueueConversationMessageEventTopicUriReference',
            'team': 'QueueConversationMessageEventTopicUriReference',
            'attributes': 'dict(str, str)',
            'error_info': 'QueueConversationMessageEventTopicErrorBody',
            'script': 'QueueConversationMessageEventTopicUriReference',
            'wrapup_timeout_ms': 'int',
            'wrapup_skipped': 'bool',
            'alerting_timeout_ms': 'int',
            'provider': 'str',
            'external_contact': 'QueueConversationMessageEventTopicUriReference',
            'external_organization': 'QueueConversationMessageEventTopicUriReference',
            'wrapup': 'QueueConversationMessageEventTopicWrapup',
            'conversation_routing_data': 'QueueConversationMessageEventTopicConversationRoutingData',
            'peer': 'str',
            'screen_recording_state': 'str',
            'flagged_reason': 'str',
            'journey_context': 'QueueConversationMessageEventTopicJourneyContext',
            'start_acw_time': 'datetime',
            'end_acw_time': 'datetime',
            'messages': 'list[QueueConversationMessageEventTopicMessageDetails]',
            'type': 'str',
            'recipient_country': 'str',
            'recipient_type': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'address': 'address',
            'start_time': 'startTime',
            'connected_time': 'connectedTime',
            'end_time': 'endTime',
            'start_hold_time': 'startHoldTime',
            'purpose': 'purpose',
            'state': 'state',
            'direction': 'direction',
            'disconnect_type': 'disconnectType',
            'held': 'held',
            'wrapup_required': 'wrapupRequired',
            'wrapup_prompt': 'wrapupPrompt',
            'user': 'user',
            'queue': 'queue',
            'team': 'team',
            'attributes': 'attributes',
            'error_info': 'errorInfo',
            'script': 'script',
            'wrapup_timeout_ms': 'wrapupTimeoutMs',
            'wrapup_skipped': 'wrapupSkipped',
            'alerting_timeout_ms': 'alertingTimeoutMs',
            'provider': 'provider',
            'external_contact': 'externalContact',
            'external_organization': 'externalOrganization',
            'wrapup': 'wrapup',
            'conversation_routing_data': 'conversationRoutingData',
            'peer': 'peer',
            'screen_recording_state': 'screenRecordingState',
            'flagged_reason': 'flaggedReason',
            'journey_context': 'journeyContext',
            'start_acw_time': 'startAcwTime',
            'end_acw_time': 'endAcwTime',
            'messages': 'messages',
            'type': 'type',
            'recipient_country': 'recipientCountry',
            'recipient_type': 'recipientType'
        }

        self._id = None
        self._name = None
        self._address = None
        self._start_time = None
        self._connected_time = None
        self._end_time = None
        self._start_hold_time = None
        self._purpose = None
        self._state = None
        self._direction = None
        self._disconnect_type = None
        self._held = None
        self._wrapup_required = None
        self._wrapup_prompt = None
        self._user = None
        self._queue = None
        self._team = None
        self._attributes = None
        self._error_info = None
        self._script = None
        self._wrapup_timeout_ms = None
        self._wrapup_skipped = None
        self._alerting_timeout_ms = None
        self._provider = None
        self._external_contact = None
        self._external_organization = None
        self._wrapup = None
        self._conversation_routing_data = None
        self._peer = None
        self._screen_recording_state = None
        self._flagged_reason = None
        self._journey_context = None
        self._start_acw_time = None
        self._end_acw_time = None
        self._messages = None
        self._type = None
        self._recipient_country = None
        self._recipient_type = None

    @property
    def id(self):
        """
        Gets the id of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The id of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param id: The id of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The name of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param name: The name of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: str
        """
        
        self._name = name

    @property
    def address(self):
        """
        Gets the address of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The address of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """
        Sets the address of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param address: The address of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: str
        """
        
        self._address = address

    @property
    def start_time(self):
        """
        Gets the start_time of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The start_time of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """
        Sets the start_time of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param start_time: The start_time of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: datetime
        """
        
        self._start_time = start_time

    @property
    def connected_time(self):
        """
        Gets the connected_time of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The connected_time of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param connected_time: The connected_time of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def end_time(self):
        """
        Gets the end_time of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The end_time of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """
        Sets the end_time of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param end_time: The end_time of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: datetime
        """
        
        self._end_time = end_time

    @property
    def start_hold_time(self):
        """
        Gets the start_hold_time of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The start_hold_time of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: datetime
        """
        return self._start_hold_time

    @start_hold_time.setter
    def start_hold_time(self, start_hold_time):
        """
        Sets the start_hold_time of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param start_hold_time: The start_hold_time of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: datetime
        """
        
        self._start_hold_time = start_hold_time

    @property
    def purpose(self):
        """
        Gets the purpose of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The purpose of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: str
        """
        return self._purpose

    @purpose.setter
    def purpose(self, purpose):
        """
        Sets the purpose of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param purpose: The purpose of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: str
        """
        
        self._purpose = purpose

    @property
    def state(self):
        """
        Gets the state of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The state of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param state: The state of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: str
        """
        allowed_values = ["alerting", "dialing", "contacting", "offering", "connected", "disconnected", "terminated", "converting", "uploading", "transmitting", "scheduled", "none"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def direction(self):
        """
        Gets the direction of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The direction of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param direction: The direction of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: str
        """
        allowed_values = ["inbound", "outbound"]
        if direction.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for direction -> " + direction)
            self._direction = "outdated_sdk_version"
        else:
            self._direction = direction

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The disconnect_type of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param disconnect_type: The disconnect_type of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: str
        """
        allowed_values = ["endpoint", "client", "system", "transfer", "timeout", "transfer.conference", "transfer.consult", "transfer.forward", "transfer.noanswer", "transfer.notavailable", "transport.failure", "error", "peer", "other", "spam", "uncallable"]
        if disconnect_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for disconnect_type -> " + disconnect_type)
            self._disconnect_type = "outdated_sdk_version"
        else:
            self._disconnect_type = disconnect_type

    @property
    def held(self):
        """
        Gets the held of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The held of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: bool
        """
        return self._held

    @held.setter
    def held(self, held):
        """
        Sets the held of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param held: The held of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: bool
        """
        
        self._held = held

    @property
    def wrapup_required(self):
        """
        Gets the wrapup_required of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The wrapup_required of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: bool
        """
        return self._wrapup_required

    @wrapup_required.setter
    def wrapup_required(self, wrapup_required):
        """
        Sets the wrapup_required of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param wrapup_required: The wrapup_required of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: bool
        """
        
        self._wrapup_required = wrapup_required

    @property
    def wrapup_prompt(self):
        """
        Gets the wrapup_prompt of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The wrapup_prompt of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: str
        """
        return self._wrapup_prompt

    @wrapup_prompt.setter
    def wrapup_prompt(self, wrapup_prompt):
        """
        Sets the wrapup_prompt of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param wrapup_prompt: The wrapup_prompt of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: str
        """
        
        self._wrapup_prompt = wrapup_prompt

    @property
    def user(self):
        """
        Gets the user of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The user of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: QueueConversationMessageEventTopicUriReference
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param user: The user of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: QueueConversationMessageEventTopicUriReference
        """
        
        self._user = user

    @property
    def queue(self):
        """
        Gets the queue of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The queue of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: QueueConversationMessageEventTopicUriReference
        """
        return self._queue

    @queue.setter
    def queue(self, queue):
        """
        Sets the queue of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param queue: The queue of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: QueueConversationMessageEventTopicUriReference
        """
        
        self._queue = queue

    @property
    def team(self):
        """
        Gets the team of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The team of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: QueueConversationMessageEventTopicUriReference
        """
        return self._team

    @team.setter
    def team(self, team):
        """
        Sets the team of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param team: The team of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: QueueConversationMessageEventTopicUriReference
        """
        
        self._team = team

    @property
    def attributes(self):
        """
        Gets the attributes of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The attributes of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: dict(str, str)
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """
        Sets the attributes of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param attributes: The attributes of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: dict(str, str)
        """
        
        self._attributes = attributes

    @property
    def error_info(self):
        """
        Gets the error_info of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The error_info of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: QueueConversationMessageEventTopicErrorBody
        """
        return self._error_info

    @error_info.setter
    def error_info(self, error_info):
        """
        Sets the error_info of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param error_info: The error_info of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: QueueConversationMessageEventTopicErrorBody
        """
        
        self._error_info = error_info

    @property
    def script(self):
        """
        Gets the script of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The script of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: QueueConversationMessageEventTopicUriReference
        """
        return self._script

    @script.setter
    def script(self, script):
        """
        Sets the script of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param script: The script of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: QueueConversationMessageEventTopicUriReference
        """
        
        self._script = script

    @property
    def wrapup_timeout_ms(self):
        """
        Gets the wrapup_timeout_ms of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The wrapup_timeout_ms of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: int
        """
        return self._wrapup_timeout_ms

    @wrapup_timeout_ms.setter
    def wrapup_timeout_ms(self, wrapup_timeout_ms):
        """
        Sets the wrapup_timeout_ms of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param wrapup_timeout_ms: The wrapup_timeout_ms of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: int
        """
        
        self._wrapup_timeout_ms = wrapup_timeout_ms

    @property
    def wrapup_skipped(self):
        """
        Gets the wrapup_skipped of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The wrapup_skipped of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: bool
        """
        return self._wrapup_skipped

    @wrapup_skipped.setter
    def wrapup_skipped(self, wrapup_skipped):
        """
        Sets the wrapup_skipped of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param wrapup_skipped: The wrapup_skipped of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: bool
        """
        
        self._wrapup_skipped = wrapup_skipped

    @property
    def alerting_timeout_ms(self):
        """
        Gets the alerting_timeout_ms of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The alerting_timeout_ms of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: int
        """
        return self._alerting_timeout_ms

    @alerting_timeout_ms.setter
    def alerting_timeout_ms(self, alerting_timeout_ms):
        """
        Sets the alerting_timeout_ms of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param alerting_timeout_ms: The alerting_timeout_ms of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: int
        """
        
        self._alerting_timeout_ms = alerting_timeout_ms

    @property
    def provider(self):
        """
        Gets the provider of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The provider of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param provider: The provider of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: str
        """
        
        self._provider = provider

    @property
    def external_contact(self):
        """
        Gets the external_contact of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The external_contact of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: QueueConversationMessageEventTopicUriReference
        """
        return self._external_contact

    @external_contact.setter
    def external_contact(self, external_contact):
        """
        Sets the external_contact of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param external_contact: The external_contact of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: QueueConversationMessageEventTopicUriReference
        """
        
        self._external_contact = external_contact

    @property
    def external_organization(self):
        """
        Gets the external_organization of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The external_organization of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: QueueConversationMessageEventTopicUriReference
        """
        return self._external_organization

    @external_organization.setter
    def external_organization(self, external_organization):
        """
        Sets the external_organization of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param external_organization: The external_organization of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: QueueConversationMessageEventTopicUriReference
        """
        
        self._external_organization = external_organization

    @property
    def wrapup(self):
        """
        Gets the wrapup of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The wrapup of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: QueueConversationMessageEventTopicWrapup
        """
        return self._wrapup

    @wrapup.setter
    def wrapup(self, wrapup):
        """
        Sets the wrapup of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param wrapup: The wrapup of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: QueueConversationMessageEventTopicWrapup
        """
        
        self._wrapup = wrapup

    @property
    def conversation_routing_data(self):
        """
        Gets the conversation_routing_data of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The conversation_routing_data of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: QueueConversationMessageEventTopicConversationRoutingData
        """
        return self._conversation_routing_data

    @conversation_routing_data.setter
    def conversation_routing_data(self, conversation_routing_data):
        """
        Sets the conversation_routing_data of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param conversation_routing_data: The conversation_routing_data of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: QueueConversationMessageEventTopicConversationRoutingData
        """
        
        self._conversation_routing_data = conversation_routing_data

    @property
    def peer(self):
        """
        Gets the peer of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The peer of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: str
        """
        return self._peer

    @peer.setter
    def peer(self, peer):
        """
        Sets the peer of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param peer: The peer of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: str
        """
        
        self._peer = peer

    @property
    def screen_recording_state(self):
        """
        Gets the screen_recording_state of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The screen_recording_state of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: str
        """
        return self._screen_recording_state

    @screen_recording_state.setter
    def screen_recording_state(self, screen_recording_state):
        """
        Sets the screen_recording_state of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param screen_recording_state: The screen_recording_state of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: str
        """
        
        self._screen_recording_state = screen_recording_state

    @property
    def flagged_reason(self):
        """
        Gets the flagged_reason of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The flagged_reason of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: str
        """
        return self._flagged_reason

    @flagged_reason.setter
    def flagged_reason(self, flagged_reason):
        """
        Sets the flagged_reason of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param flagged_reason: The flagged_reason of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: str
        """
        allowed_values = ["general"]
        if flagged_reason.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for flagged_reason -> " + flagged_reason)
            self._flagged_reason = "outdated_sdk_version"
        else:
            self._flagged_reason = flagged_reason

    @property
    def journey_context(self):
        """
        Gets the journey_context of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The journey_context of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: QueueConversationMessageEventTopicJourneyContext
        """
        return self._journey_context

    @journey_context.setter
    def journey_context(self, journey_context):
        """
        Sets the journey_context of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param journey_context: The journey_context of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: QueueConversationMessageEventTopicJourneyContext
        """
        
        self._journey_context = journey_context

    @property
    def start_acw_time(self):
        """
        Gets the start_acw_time of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The start_acw_time of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: datetime
        """
        return self._start_acw_time

    @start_acw_time.setter
    def start_acw_time(self, start_acw_time):
        """
        Sets the start_acw_time of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param start_acw_time: The start_acw_time of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: datetime
        """
        
        self._start_acw_time = start_acw_time

    @property
    def end_acw_time(self):
        """
        Gets the end_acw_time of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The end_acw_time of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: datetime
        """
        return self._end_acw_time

    @end_acw_time.setter
    def end_acw_time(self, end_acw_time):
        """
        Sets the end_acw_time of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param end_acw_time: The end_acw_time of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: datetime
        """
        
        self._end_acw_time = end_acw_time

    @property
    def messages(self):
        """
        Gets the messages of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The messages of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: list[QueueConversationMessageEventTopicMessageDetails]
        """
        return self._messages

    @messages.setter
    def messages(self, messages):
        """
        Sets the messages of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param messages: The messages of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: list[QueueConversationMessageEventTopicMessageDetails]
        """
        
        self._messages = messages

    @property
    def type(self):
        """
        Gets the type of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The type of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param type: The type of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: str
        """
        allowed_values = ["UNKNOWN", "SMS", "TWITTER", "FACEBOOK", "LINE", "VIBER", "WECHAT", "WHATSAPP", "TELEGRAM", "KAKAO", "WEBMESSAGING"]
        if type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for type -> " + type)
            self._type = "outdated_sdk_version"
        else:
            self._type = type

    @property
    def recipient_country(self):
        """
        Gets the recipient_country of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The recipient_country of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: str
        """
        return self._recipient_country

    @recipient_country.setter
    def recipient_country(self, recipient_country):
        """
        Sets the recipient_country of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param recipient_country: The recipient_country of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: str
        """
        
        self._recipient_country = recipient_country

    @property
    def recipient_type(self):
        """
        Gets the recipient_type of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :return: The recipient_type of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :rtype: str
        """
        return self._recipient_type

    @recipient_type.setter
    def recipient_type(self, recipient_type):
        """
        Sets the recipient_type of this QueueConversationMessageEventTopicMessageMediaParticipant.


        :param recipient_type: The recipient_type of this QueueConversationMessageEventTopicMessageMediaParticipant.
        :type: str
        """
        
        self._recipient_type = recipient_type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class BuCurrentAgentScheduleSearchResponse(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        BuCurrentAgentScheduleSearchResponse - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'agent_schedules': 'list[BuAgentScheduleSearchResponse]',
            'business_unit_time_zone': 'str',
            'published_schedules': 'list[BuAgentSchedulePublishedScheduleReference]',
            'start_date': 'datetime',
            'end_date': 'datetime',
            'updates': 'list[BuAgentScheduleUpdate]'
        }

        self.attribute_map = {
            'agent_schedules': 'agentSchedules',
            'business_unit_time_zone': 'businessUnitTimeZone',
            'published_schedules': 'publishedSchedules',
            'start_date': 'startDate',
            'end_date': 'endDate',
            'updates': 'updates'
        }

        self._agent_schedules = None
        self._business_unit_time_zone = None
        self._published_schedules = None
        self._start_date = None
        self._end_date = None
        self._updates = None

    @property
    def agent_schedules(self):
        """
        Gets the agent_schedules of this BuCurrentAgentScheduleSearchResponse.
        The requested agent schedules

        :return: The agent_schedules of this BuCurrentAgentScheduleSearchResponse.
        :rtype: list[BuAgentScheduleSearchResponse]
        """
        return self._agent_schedules

    @agent_schedules.setter
    def agent_schedules(self, agent_schedules):
        """
        Sets the agent_schedules of this BuCurrentAgentScheduleSearchResponse.
        The requested agent schedules

        :param agent_schedules: The agent_schedules of this BuCurrentAgentScheduleSearchResponse.
        :type: list[BuAgentScheduleSearchResponse]
        """
        
        self._agent_schedules = agent_schedules

    @property
    def business_unit_time_zone(self):
        """
        Gets the business_unit_time_zone of this BuCurrentAgentScheduleSearchResponse.
        The time zone configured for the business unit to which this schedule applies

        :return: The business_unit_time_zone of this BuCurrentAgentScheduleSearchResponse.
        :rtype: str
        """
        return self._business_unit_time_zone

    @business_unit_time_zone.setter
    def business_unit_time_zone(self, business_unit_time_zone):
        """
        Sets the business_unit_time_zone of this BuCurrentAgentScheduleSearchResponse.
        The time zone configured for the business unit to which this schedule applies

        :param business_unit_time_zone: The business_unit_time_zone of this BuCurrentAgentScheduleSearchResponse.
        :type: str
        """
        
        self._business_unit_time_zone = business_unit_time_zone

    @property
    def published_schedules(self):
        """
        Gets the published_schedules of this BuCurrentAgentScheduleSearchResponse.
        References to all published week schedules overlapping the start/end date query parameters

        :return: The published_schedules of this BuCurrentAgentScheduleSearchResponse.
        :rtype: list[BuAgentSchedulePublishedScheduleReference]
        """
        return self._published_schedules

    @published_schedules.setter
    def published_schedules(self, published_schedules):
        """
        Sets the published_schedules of this BuCurrentAgentScheduleSearchResponse.
        References to all published week schedules overlapping the start/end date query parameters

        :param published_schedules: The published_schedules of this BuCurrentAgentScheduleSearchResponse.
        :type: list[BuAgentSchedulePublishedScheduleReference]
        """
        
        self._published_schedules = published_schedules

    @property
    def start_date(self):
        """
        Gets the start_date of this BuCurrentAgentScheduleSearchResponse.
        The start date of the schedules. Only populated on notifications. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The start_date of this BuCurrentAgentScheduleSearchResponse.
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """
        Sets the start_date of this BuCurrentAgentScheduleSearchResponse.
        The start date of the schedules. Only populated on notifications. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param start_date: The start_date of this BuCurrentAgentScheduleSearchResponse.
        :type: datetime
        """
        
        self._start_date = start_date

    @property
    def end_date(self):
        """
        Gets the end_date of this BuCurrentAgentScheduleSearchResponse.
        The end date of the schedules. Only populated on notifications. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The end_date of this BuCurrentAgentScheduleSearchResponse.
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """
        Sets the end_date of this BuCurrentAgentScheduleSearchResponse.
        The end date of the schedules. Only populated on notifications. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param end_date: The end_date of this BuCurrentAgentScheduleSearchResponse.
        :type: datetime
        """
        
        self._end_date = end_date

    @property
    def updates(self):
        """
        Gets the updates of this BuCurrentAgentScheduleSearchResponse.
        The list of updates for the schedule. Only used in notifications

        :return: The updates of this BuCurrentAgentScheduleSearchResponse.
        :rtype: list[BuAgentScheduleUpdate]
        """
        return self._updates

    @updates.setter
    def updates(self, updates):
        """
        Sets the updates of this BuCurrentAgentScheduleSearchResponse.
        The list of updates for the schedule. Only used in notifications

        :param updates: The updates of this BuCurrentAgentScheduleSearchResponse.
        :type: list[BuAgentScheduleUpdate]
        """
        
        self._updates = updates

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class DialerContactlistfilterConfigChangeFilterPredicate(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DialerContactlistfilterConfigChangeFilterPredicate - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'column': 'str',
            'column_type': 'str',
            'operator': 'str',
            'value': 'str',
            'range': 'DialerContactlistfilterConfigChangeRange',
            'inverted': 'bool',
            'additional_properties': 'object'
        }

        self.attribute_map = {
            'column': 'column',
            'column_type': 'columnType',
            'operator': 'operator',
            'value': 'value',
            'range': 'range',
            'inverted': 'inverted',
            'additional_properties': 'additionalProperties'
        }

        self._column = None
        self._column_type = None
        self._operator = None
        self._value = None
        self._range = None
        self._inverted = None
        self._additional_properties = None

    @property
    def column(self):
        """
        Gets the column of this DialerContactlistfilterConfigChangeFilterPredicate.


        :return: The column of this DialerContactlistfilterConfigChangeFilterPredicate.
        :rtype: str
        """
        return self._column

    @column.setter
    def column(self, column):
        """
        Sets the column of this DialerContactlistfilterConfigChangeFilterPredicate.


        :param column: The column of this DialerContactlistfilterConfigChangeFilterPredicate.
        :type: str
        """
        
        self._column = column

    @property
    def column_type(self):
        """
        Gets the column_type of this DialerContactlistfilterConfigChangeFilterPredicate.


        :return: The column_type of this DialerContactlistfilterConfigChangeFilterPredicate.
        :rtype: str
        """
        return self._column_type

    @column_type.setter
    def column_type(self, column_type):
        """
        Sets the column_type of this DialerContactlistfilterConfigChangeFilterPredicate.


        :param column_type: The column_type of this DialerContactlistfilterConfigChangeFilterPredicate.
        :type: str
        """
        allowed_values = ["NUMERIC", "ALPHABETIC"]
        if column_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for column_type -> " + column_type)
            self._column_type = "outdated_sdk_version"
        else:
            self._column_type = column_type

    @property
    def operator(self):
        """
        Gets the operator of this DialerContactlistfilterConfigChangeFilterPredicate.


        :return: The operator of this DialerContactlistfilterConfigChangeFilterPredicate.
        :rtype: str
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """
        Sets the operator of this DialerContactlistfilterConfigChangeFilterPredicate.


        :param operator: The operator of this DialerContactlistfilterConfigChangeFilterPredicate.
        :type: str
        """
        allowed_values = ["EQUALS", "LESS_THAN", "LESS_THAN_EQUALS", "GREATER_THAN", "GREATER_THAN_EQUALS", "CONTAINS", "BEGINS_WITH", "ENDS_WITH", "BEFORE", "AFTER", "BETWEEN", "IN"]
        if operator.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for operator -> " + operator)
            self._operator = "outdated_sdk_version"
        else:
            self._operator = operator

    @property
    def value(self):
        """
        Gets the value of this DialerContactlistfilterConfigChangeFilterPredicate.


        :return: The value of this DialerContactlistfilterConfigChangeFilterPredicate.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this DialerContactlistfilterConfigChangeFilterPredicate.


        :param value: The value of this DialerContactlistfilterConfigChangeFilterPredicate.
        :type: str
        """
        
        self._value = value

    @property
    def range(self):
        """
        Gets the range of this DialerContactlistfilterConfigChangeFilterPredicate.


        :return: The range of this DialerContactlistfilterConfigChangeFilterPredicate.
        :rtype: DialerContactlistfilterConfigChangeRange
        """
        return self._range

    @range.setter
    def range(self, range):
        """
        Sets the range of this DialerContactlistfilterConfigChangeFilterPredicate.


        :param range: The range of this DialerContactlistfilterConfigChangeFilterPredicate.
        :type: DialerContactlistfilterConfigChangeRange
        """
        
        self._range = range

    @property
    def inverted(self):
        """
        Gets the inverted of this DialerContactlistfilterConfigChangeFilterPredicate.


        :return: The inverted of this DialerContactlistfilterConfigChangeFilterPredicate.
        :rtype: bool
        """
        return self._inverted

    @inverted.setter
    def inverted(self, inverted):
        """
        Sets the inverted of this DialerContactlistfilterConfigChangeFilterPredicate.


        :param inverted: The inverted of this DialerContactlistfilterConfigChangeFilterPredicate.
        :type: bool
        """
        
        self._inverted = inverted

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this DialerContactlistfilterConfigChangeFilterPredicate.


        :return: The additional_properties of this DialerContactlistfilterConfigChangeFilterPredicate.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this DialerContactlistfilterConfigChangeFilterPredicate.


        :param additional_properties: The additional_properties of this DialerContactlistfilterConfigChangeFilterPredicate.
        :type: object
        """
        
        self._additional_properties = additional_properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class DialerSequenceConfigChangeCampaignSequence(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DialerSequenceConfigChangeCampaignSequence - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'version': 'int',
            'campaigns': 'list[DialerSequenceConfigChangeUriReference]',
            'current_campaign': 'int',
            'status': 'str',
            'stop_message': 'str',
            'repeat': 'bool',
            'additional_properties': 'object'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'version': 'version',
            'campaigns': 'campaigns',
            'current_campaign': 'currentCampaign',
            'status': 'status',
            'stop_message': 'stopMessage',
            'repeat': 'repeat',
            'additional_properties': 'additionalProperties'
        }

        self._id = None
        self._name = None
        self._date_created = None
        self._date_modified = None
        self._version = None
        self._campaigns = None
        self._current_campaign = None
        self._status = None
        self._stop_message = None
        self._repeat = None
        self._additional_properties = None

    @property
    def id(self):
        """
        Gets the id of this DialerSequenceConfigChangeCampaignSequence.


        :return: The id of this DialerSequenceConfigChangeCampaignSequence.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DialerSequenceConfigChangeCampaignSequence.


        :param id: The id of this DialerSequenceConfigChangeCampaignSequence.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this DialerSequenceConfigChangeCampaignSequence.


        :return: The name of this DialerSequenceConfigChangeCampaignSequence.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DialerSequenceConfigChangeCampaignSequence.


        :param name: The name of this DialerSequenceConfigChangeCampaignSequence.
        :type: str
        """
        
        self._name = name

    @property
    def date_created(self):
        """
        Gets the date_created of this DialerSequenceConfigChangeCampaignSequence.


        :return: The date_created of this DialerSequenceConfigChangeCampaignSequence.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this DialerSequenceConfigChangeCampaignSequence.


        :param date_created: The date_created of this DialerSequenceConfigChangeCampaignSequence.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this DialerSequenceConfigChangeCampaignSequence.


        :return: The date_modified of this DialerSequenceConfigChangeCampaignSequence.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this DialerSequenceConfigChangeCampaignSequence.


        :param date_modified: The date_modified of this DialerSequenceConfigChangeCampaignSequence.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def version(self):
        """
        Gets the version of this DialerSequenceConfigChangeCampaignSequence.


        :return: The version of this DialerSequenceConfigChangeCampaignSequence.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this DialerSequenceConfigChangeCampaignSequence.


        :param version: The version of this DialerSequenceConfigChangeCampaignSequence.
        :type: int
        """
        
        self._version = version

    @property
    def campaigns(self):
        """
        Gets the campaigns of this DialerSequenceConfigChangeCampaignSequence.


        :return: The campaigns of this DialerSequenceConfigChangeCampaignSequence.
        :rtype: list[DialerSequenceConfigChangeUriReference]
        """
        return self._campaigns

    @campaigns.setter
    def campaigns(self, campaigns):
        """
        Sets the campaigns of this DialerSequenceConfigChangeCampaignSequence.


        :param campaigns: The campaigns of this DialerSequenceConfigChangeCampaignSequence.
        :type: list[DialerSequenceConfigChangeUriReference]
        """
        
        self._campaigns = campaigns

    @property
    def current_campaign(self):
        """
        Gets the current_campaign of this DialerSequenceConfigChangeCampaignSequence.


        :return: The current_campaign of this DialerSequenceConfigChangeCampaignSequence.
        :rtype: int
        """
        return self._current_campaign

    @current_campaign.setter
    def current_campaign(self, current_campaign):
        """
        Sets the current_campaign of this DialerSequenceConfigChangeCampaignSequence.


        :param current_campaign: The current_campaign of this DialerSequenceConfigChangeCampaignSequence.
        :type: int
        """
        
        self._current_campaign = current_campaign

    @property
    def status(self):
        """
        Gets the status of this DialerSequenceConfigChangeCampaignSequence.


        :return: The status of this DialerSequenceConfigChangeCampaignSequence.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this DialerSequenceConfigChangeCampaignSequence.


        :param status: The status of this DialerSequenceConfigChangeCampaignSequence.
        :type: str
        """
        allowed_values = ["ON", "OFF", "COMPLETE"]
        if status.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for status -> " + status)
            self._status = "outdated_sdk_version"
        else:
            self._status = status

    @property
    def stop_message(self):
        """
        Gets the stop_message of this DialerSequenceConfigChangeCampaignSequence.


        :return: The stop_message of this DialerSequenceConfigChangeCampaignSequence.
        :rtype: str
        """
        return self._stop_message

    @stop_message.setter
    def stop_message(self, stop_message):
        """
        Sets the stop_message of this DialerSequenceConfigChangeCampaignSequence.


        :param stop_message: The stop_message of this DialerSequenceConfigChangeCampaignSequence.
        :type: str
        """
        
        self._stop_message = stop_message

    @property
    def repeat(self):
        """
        Gets the repeat of this DialerSequenceConfigChangeCampaignSequence.


        :return: The repeat of this DialerSequenceConfigChangeCampaignSequence.
        :rtype: bool
        """
        return self._repeat

    @repeat.setter
    def repeat(self, repeat):
        """
        Sets the repeat of this DialerSequenceConfigChangeCampaignSequence.


        :param repeat: The repeat of this DialerSequenceConfigChangeCampaignSequence.
        :type: bool
        """
        
        self._repeat = repeat

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this DialerSequenceConfigChangeCampaignSequence.


        :return: The additional_properties of this DialerSequenceConfigChangeCampaignSequence.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this DialerSequenceConfigChangeCampaignSequence.


        :param additional_properties: The additional_properties of this DialerSequenceConfigChangeCampaignSequence.
        :type: object
        """
        
        self._additional_properties = additional_properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class WorkPlanRotationResponse(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        WorkPlanRotationResponse - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'enabled': 'bool',
            'date_range': 'DateRangeWithOptionalEnd',
            'pattern': 'WorkPlanPatternResponse',
            'agent_count': 'int',
            'agents': 'list[WorkPlanRotationAgentResponse]',
            'metadata': 'WfmVersionedEntityMetadata',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'enabled': 'enabled',
            'date_range': 'dateRange',
            'pattern': 'pattern',
            'agent_count': 'agentCount',
            'agents': 'agents',
            'metadata': 'metadata',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._enabled = None
        self._date_range = None
        self._pattern = None
        self._agent_count = None
        self._agents = None
        self._metadata = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this WorkPlanRotationResponse.
        The globally unique identifier for the object.

        :return: The id of this WorkPlanRotationResponse.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this WorkPlanRotationResponse.
        The globally unique identifier for the object.

        :param id: The id of this WorkPlanRotationResponse.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this WorkPlanRotationResponse.


        :return: The name of this WorkPlanRotationResponse.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this WorkPlanRotationResponse.


        :param name: The name of this WorkPlanRotationResponse.
        :type: str
        """
        
        self._name = name

    @property
    def enabled(self):
        """
        Gets the enabled of this WorkPlanRotationResponse.
        Whether the work plan rotation is enabled for scheduling

        :return: The enabled of this WorkPlanRotationResponse.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this WorkPlanRotationResponse.
        Whether the work plan rotation is enabled for scheduling

        :param enabled: The enabled of this WorkPlanRotationResponse.
        :type: bool
        """
        
        self._enabled = enabled

    @property
    def date_range(self):
        """
        Gets the date_range of this WorkPlanRotationResponse.
        The date range to which this work plan rotation applies

        :return: The date_range of this WorkPlanRotationResponse.
        :rtype: DateRangeWithOptionalEnd
        """
        return self._date_range

    @date_range.setter
    def date_range(self, date_range):
        """
        Sets the date_range of this WorkPlanRotationResponse.
        The date range to which this work plan rotation applies

        :param date_range: The date_range of this WorkPlanRotationResponse.
        :type: DateRangeWithOptionalEnd
        """
        
        self._date_range = date_range

    @property
    def pattern(self):
        """
        Gets the pattern of this WorkPlanRotationResponse.
        Pattern with ordered list of work plans that rotate on a weekly basis

        :return: The pattern of this WorkPlanRotationResponse.
        :rtype: WorkPlanPatternResponse
        """
        return self._pattern

    @pattern.setter
    def pattern(self, pattern):
        """
        Sets the pattern of this WorkPlanRotationResponse.
        Pattern with ordered list of work plans that rotate on a weekly basis

        :param pattern: The pattern of this WorkPlanRotationResponse.
        :type: WorkPlanPatternResponse
        """
        
        self._pattern = pattern

    @property
    def agent_count(self):
        """
        Gets the agent_count of this WorkPlanRotationResponse.
        Number of agents in this work plan rotation

        :return: The agent_count of this WorkPlanRotationResponse.
        :rtype: int
        """
        return self._agent_count

    @agent_count.setter
    def agent_count(self, agent_count):
        """
        Sets the agent_count of this WorkPlanRotationResponse.
        Number of agents in this work plan rotation

        :param agent_count: The agent_count of this WorkPlanRotationResponse.
        :type: int
        """
        
        self._agent_count = agent_count

    @property
    def agents(self):
        """
        Gets the agents of this WorkPlanRotationResponse.
        Agents in this work plan rotation. Populate with expand=agents for GET WorkPlanRotationsList (defaults to empty list)

        :return: The agents of this WorkPlanRotationResponse.
        :rtype: list[WorkPlanRotationAgentResponse]
        """
        return self._agents

    @agents.setter
    def agents(self, agents):
        """
        Sets the agents of this WorkPlanRotationResponse.
        Agents in this work plan rotation. Populate with expand=agents for GET WorkPlanRotationsList (defaults to empty list)

        :param agents: The agents of this WorkPlanRotationResponse.
        :type: list[WorkPlanRotationAgentResponse]
        """
        
        self._agents = agents

    @property
    def metadata(self):
        """
        Gets the metadata of this WorkPlanRotationResponse.
        Version metadata for this work plan rotation

        :return: The metadata of this WorkPlanRotationResponse.
        :rtype: WfmVersionedEntityMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this WorkPlanRotationResponse.
        Version metadata for this work plan rotation

        :param metadata: The metadata of this WorkPlanRotationResponse.
        :type: WfmVersionedEntityMetadata
        """
        
        self._metadata = metadata

    @property
    def self_uri(self):
        """
        Gets the self_uri of this WorkPlanRotationResponse.
        The URI for this object

        :return: The self_uri of this WorkPlanRotationResponse.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this WorkPlanRotationResponse.
        The URI for this object

        :param self_uri: The self_uri of this WorkPlanRotationResponse.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class CampaignRule(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        CampaignRule - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'version': 'int',
            'campaign_rule_entities': 'CampaignRuleEntities',
            'campaign_rule_conditions': 'list[CampaignRuleCondition]',
            'campaign_rule_actions': 'list[CampaignRuleAction]',
            'match_any_conditions': 'bool',
            'enabled': 'bool',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'version': 'version',
            'campaign_rule_entities': 'campaignRuleEntities',
            'campaign_rule_conditions': 'campaignRuleConditions',
            'campaign_rule_actions': 'campaignRuleActions',
            'match_any_conditions': 'matchAnyConditions',
            'enabled': 'enabled',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._date_created = None
        self._date_modified = None
        self._version = None
        self._campaign_rule_entities = None
        self._campaign_rule_conditions = None
        self._campaign_rule_actions = None
        self._match_any_conditions = None
        self._enabled = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this CampaignRule.
        The globally unique identifier for the object.

        :return: The id of this CampaignRule.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this CampaignRule.
        The globally unique identifier for the object.

        :param id: The id of this CampaignRule.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this CampaignRule.
        The name of the CampaignRule.

        :return: The name of this CampaignRule.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CampaignRule.
        The name of the CampaignRule.

        :param name: The name of this CampaignRule.
        :type: str
        """
        
        self._name = name

    @property
    def date_created(self):
        """
        Gets the date_created of this CampaignRule.
        Creation time of the entity. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_created of this CampaignRule.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this CampaignRule.
        Creation time of the entity. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_created: The date_created of this CampaignRule.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this CampaignRule.
        Last modified time of the entity. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_modified of this CampaignRule.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this CampaignRule.
        Last modified time of the entity. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_modified: The date_modified of this CampaignRule.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def version(self):
        """
        Gets the version of this CampaignRule.
        Required for updates, must match the version number of the most recent update

        :return: The version of this CampaignRule.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this CampaignRule.
        Required for updates, must match the version number of the most recent update

        :param version: The version of this CampaignRule.
        :type: int
        """
        
        self._version = version

    @property
    def campaign_rule_entities(self):
        """
        Gets the campaign_rule_entities of this CampaignRule.
        The list of entities that this CampaignRule monitors.

        :return: The campaign_rule_entities of this CampaignRule.
        :rtype: CampaignRuleEntities
        """
        return self._campaign_rule_entities

    @campaign_rule_entities.setter
    def campaign_rule_entities(self, campaign_rule_entities):
        """
        Sets the campaign_rule_entities of this CampaignRule.
        The list of entities that this CampaignRule monitors.

        :param campaign_rule_entities: The campaign_rule_entities of this CampaignRule.
        :type: CampaignRuleEntities
        """
        
        self._campaign_rule_entities = campaign_rule_entities

    @property
    def campaign_rule_conditions(self):
        """
        Gets the campaign_rule_conditions of this CampaignRule.
        The list of conditions that are evaluated on the entities.

        :return: The campaign_rule_conditions of this CampaignRule.
        :rtype: list[CampaignRuleCondition]
        """
        return self._campaign_rule_conditions

    @campaign_rule_conditions.setter
    def campaign_rule_conditions(self, campaign_rule_conditions):
        """
        Sets the campaign_rule_conditions of this CampaignRule.
        The list of conditions that are evaluated on the entities.

        :param campaign_rule_conditions: The campaign_rule_conditions of this CampaignRule.
        :type: list[CampaignRuleCondition]
        """
        
        self._campaign_rule_conditions = campaign_rule_conditions

    @property
    def campaign_rule_actions(self):
        """
        Gets the campaign_rule_actions of this CampaignRule.
        The list of actions that are executed if the conditions are satisfied.

        :return: The campaign_rule_actions of this CampaignRule.
        :rtype: list[CampaignRuleAction]
        """
        return self._campaign_rule_actions

    @campaign_rule_actions.setter
    def campaign_rule_actions(self, campaign_rule_actions):
        """
        Sets the campaign_rule_actions of this CampaignRule.
        The list of actions that are executed if the conditions are satisfied.

        :param campaign_rule_actions: The campaign_rule_actions of this CampaignRule.
        :type: list[CampaignRuleAction]
        """
        
        self._campaign_rule_actions = campaign_rule_actions

    @property
    def match_any_conditions(self):
        """
        Gets the match_any_conditions of this CampaignRule.


        :return: The match_any_conditions of this CampaignRule.
        :rtype: bool
        """
        return self._match_any_conditions

    @match_any_conditions.setter
    def match_any_conditions(self, match_any_conditions):
        """
        Sets the match_any_conditions of this CampaignRule.


        :param match_any_conditions: The match_any_conditions of this CampaignRule.
        :type: bool
        """
        
        self._match_any_conditions = match_any_conditions

    @property
    def enabled(self):
        """
        Gets the enabled of this CampaignRule.
        Whether or not this CampaignRule is currently enabled. Required on updates.

        :return: The enabled of this CampaignRule.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this CampaignRule.
        Whether or not this CampaignRule is currently enabled. Required on updates.

        :param enabled: The enabled of this CampaignRule.
        :type: bool
        """
        
        self._enabled = enabled

    @property
    def self_uri(self):
        """
        Gets the self_uri of this CampaignRule.
        The URI for this object

        :return: The self_uri of this CampaignRule.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this CampaignRule.
        The URI for this object

        :param self_uri: The self_uri of this CampaignRule.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class QueueConversationEventTopicChat(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        QueueConversationEventTopicChat - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'state': 'str',
            'id': 'str',
            'provider': 'str',
            'script_id': 'str',
            'peer_id': 'str',
            'room_id': 'str',
            'avatar_image_url': 'str',
            'held': 'bool',
            'disconnect_type': 'str',
            'start_hold_time': 'datetime',
            'connected_time': 'datetime',
            'disconnected_time': 'datetime',
            'journey_context': 'QueueConversationEventTopicJourneyContext',
            'wrapup': 'QueueConversationEventTopicWrapup',
            'after_call_work': 'QueueConversationEventTopicAfterCallWork',
            'after_call_work_required': 'bool',
            'additional_properties': 'object'
        }

        self.attribute_map = {
            'state': 'state',
            'id': 'id',
            'provider': 'provider',
            'script_id': 'scriptId',
            'peer_id': 'peerId',
            'room_id': 'roomId',
            'avatar_image_url': 'avatarImageUrl',
            'held': 'held',
            'disconnect_type': 'disconnectType',
            'start_hold_time': 'startHoldTime',
            'connected_time': 'connectedTime',
            'disconnected_time': 'disconnectedTime',
            'journey_context': 'journeyContext',
            'wrapup': 'wrapup',
            'after_call_work': 'afterCallWork',
            'after_call_work_required': 'afterCallWorkRequired',
            'additional_properties': 'additionalProperties'
        }

        self._state = None
        self._id = None
        self._provider = None
        self._script_id = None
        self._peer_id = None
        self._room_id = None
        self._avatar_image_url = None
        self._held = None
        self._disconnect_type = None
        self._start_hold_time = None
        self._connected_time = None
        self._disconnected_time = None
        self._journey_context = None
        self._wrapup = None
        self._after_call_work = None
        self._after_call_work_required = None
        self._additional_properties = None

    @property
    def state(self):
        """
        Gets the state of this QueueConversationEventTopicChat.


        :return: The state of this QueueConversationEventTopicChat.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this QueueConversationEventTopicChat.


        :param state: The state of this QueueConversationEventTopicChat.
        :type: str
        """
        allowed_values = ["ALERTING", "DIALING", "CONTACTING", "OFFERING", "CONNECTED", "DISCONNECTED", "TERMINATED", "NONE"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def id(self):
        """
        Gets the id of this QueueConversationEventTopicChat.


        :return: The id of this QueueConversationEventTopicChat.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this QueueConversationEventTopicChat.


        :param id: The id of this QueueConversationEventTopicChat.
        :type: str
        """
        
        self._id = id

    @property
    def provider(self):
        """
        Gets the provider of this QueueConversationEventTopicChat.


        :return: The provider of this QueueConversationEventTopicChat.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this QueueConversationEventTopicChat.


        :param provider: The provider of this QueueConversationEventTopicChat.
        :type: str
        """
        
        self._provider = provider

    @property
    def script_id(self):
        """
        Gets the script_id of this QueueConversationEventTopicChat.


        :return: The script_id of this QueueConversationEventTopicChat.
        :rtype: str
        """
        return self._script_id

    @script_id.setter
    def script_id(self, script_id):
        """
        Sets the script_id of this QueueConversationEventTopicChat.


        :param script_id: The script_id of this QueueConversationEventTopicChat.
        :type: str
        """
        
        self._script_id = script_id

    @property
    def peer_id(self):
        """
        Gets the peer_id of this QueueConversationEventTopicChat.


        :return: The peer_id of this QueueConversationEventTopicChat.
        :rtype: str
        """
        return self._peer_id

    @peer_id.setter
    def peer_id(self, peer_id):
        """
        Sets the peer_id of this QueueConversationEventTopicChat.


        :param peer_id: The peer_id of this QueueConversationEventTopicChat.
        :type: str
        """
        
        self._peer_id = peer_id

    @property
    def room_id(self):
        """
        Gets the room_id of this QueueConversationEventTopicChat.


        :return: The room_id of this QueueConversationEventTopicChat.
        :rtype: str
        """
        return self._room_id

    @room_id.setter
    def room_id(self, room_id):
        """
        Sets the room_id of this QueueConversationEventTopicChat.


        :param room_id: The room_id of this QueueConversationEventTopicChat.
        :type: str
        """
        
        self._room_id = room_id

    @property
    def avatar_image_url(self):
        """
        Gets the avatar_image_url of this QueueConversationEventTopicChat.


        :return: The avatar_image_url of this QueueConversationEventTopicChat.
        :rtype: str
        """
        return self._avatar_image_url

    @avatar_image_url.setter
    def avatar_image_url(self, avatar_image_url):
        """
        Sets the avatar_image_url of this QueueConversationEventTopicChat.


        :param avatar_image_url: The avatar_image_url of this QueueConversationEventTopicChat.
        :type: str
        """
        
        self._avatar_image_url = avatar_image_url

    @property
    def held(self):
        """
        Gets the held of this QueueConversationEventTopicChat.


        :return: The held of this QueueConversationEventTopicChat.
        :rtype: bool
        """
        return self._held

    @held.setter
    def held(self, held):
        """
        Sets the held of this QueueConversationEventTopicChat.


        :param held: The held of this QueueConversationEventTopicChat.
        :type: bool
        """
        
        self._held = held

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this QueueConversationEventTopicChat.


        :return: The disconnect_type of this QueueConversationEventTopicChat.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this QueueConversationEventTopicChat.


        :param disconnect_type: The disconnect_type of this QueueConversationEventTopicChat.
        :type: str
        """
        allowed_values = ["ENDPOINT", "CLIENT", "SYSTEM", "TIMEOUT", "TRANSFER", "TRANSFER_CONFERENCE", "TRANSFER_CONSULT", "TRANSFER_NOANSWER", "TRANSFER_NOTAVAILABLE", "TRANSFER_FORWARD", "TRANSPORT_FAILURE", "ERROR", "PEER", "OTHER", "SPAM", "UNCALLABLE"]
        if disconnect_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for disconnect_type -> " + disconnect_type)
            self._disconnect_type = "outdated_sdk_version"
        else:
            self._disconnect_type = disconnect_type

    @property
    def start_hold_time(self):
        """
        Gets the start_hold_time of this QueueConversationEventTopicChat.


        :return: The start_hold_time of this QueueConversationEventTopicChat.
        :rtype: datetime
        """
        return self._start_hold_time

    @start_hold_time.setter
    def start_hold_time(self, start_hold_time):
        """
        Sets the start_hold_time of this QueueConversationEventTopicChat.


        :param start_hold_time: The start_hold_time of this QueueConversationEventTopicChat.
        :type: datetime
        """
        
        self._start_hold_time = start_hold_time

    @property
    def connected_time(self):
        """
        Gets the connected_time of this QueueConversationEventTopicChat.


        :return: The connected_time of this QueueConversationEventTopicChat.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this QueueConversationEventTopicChat.


        :param connected_time: The connected_time of this QueueConversationEventTopicChat.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def disconnected_time(self):
        """
        Gets the disconnected_time of this QueueConversationEventTopicChat.


        :return: The disconnected_time of this QueueConversationEventTopicChat.
        :rtype: datetime
        """
        return self._disconnected_time

    @disconnected_time.setter
    def disconnected_time(self, disconnected_time):
        """
        Sets the disconnected_time of this QueueConversationEventTopicChat.


        :param disconnected_time: The disconnected_time of this QueueConversationEventTopicChat.
        :type: datetime
        """
        
        self._disconnected_time = disconnected_time

    @property
    def journey_context(self):
        """
        Gets the journey_context of this QueueConversationEventTopicChat.


        :return: The journey_context of this QueueConversationEventTopicChat.
        :rtype: QueueConversationEventTopicJourneyContext
        """
        return self._journey_context

    @journey_context.setter
    def journey_context(self, journey_context):
        """
        Sets the journey_context of this QueueConversationEventTopicChat.


        :param journey_context: The journey_context of this QueueConversationEventTopicChat.
        :type: QueueConversationEventTopicJourneyContext
        """
        
        self._journey_context = journey_context

    @property
    def wrapup(self):
        """
        Gets the wrapup of this QueueConversationEventTopicChat.


        :return: The wrapup of this QueueConversationEventTopicChat.
        :rtype: QueueConversationEventTopicWrapup
        """
        return self._wrapup

    @wrapup.setter
    def wrapup(self, wrapup):
        """
        Sets the wrapup of this QueueConversationEventTopicChat.


        :param wrapup: The wrapup of this QueueConversationEventTopicChat.
        :type: QueueConversationEventTopicWrapup
        """
        
        self._wrapup = wrapup

    @property
    def after_call_work(self):
        """
        Gets the after_call_work of this QueueConversationEventTopicChat.


        :return: The after_call_work of this QueueConversationEventTopicChat.
        :rtype: QueueConversationEventTopicAfterCallWork
        """
        return self._after_call_work

    @after_call_work.setter
    def after_call_work(self, after_call_work):
        """
        Sets the after_call_work of this QueueConversationEventTopicChat.


        :param after_call_work: The after_call_work of this QueueConversationEventTopicChat.
        :type: QueueConversationEventTopicAfterCallWork
        """
        
        self._after_call_work = after_call_work

    @property
    def after_call_work_required(self):
        """
        Gets the after_call_work_required of this QueueConversationEventTopicChat.


        :return: The after_call_work_required of this QueueConversationEventTopicChat.
        :rtype: bool
        """
        return self._after_call_work_required

    @after_call_work_required.setter
    def after_call_work_required(self, after_call_work_required):
        """
        Sets the after_call_work_required of this QueueConversationEventTopicChat.


        :param after_call_work_required: The after_call_work_required of this QueueConversationEventTopicChat.
        :type: bool
        """
        
        self._after_call_work_required = after_call_work_required

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this QueueConversationEventTopicChat.


        :return: The additional_properties of this QueueConversationEventTopicChat.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this QueueConversationEventTopicChat.


        :param additional_properties: The additional_properties of this QueueConversationEventTopicChat.
        :type: object
        """
        
        self._additional_properties = additional_properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ConversationAssociation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ConversationAssociation - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'external_contact_id': 'str',
            'conversation_id': 'str',
            'communication_id': 'str',
            'media_type': 'str'
        }

        self.attribute_map = {
            'external_contact_id': 'externalContactId',
            'conversation_id': 'conversationId',
            'communication_id': 'communicationId',
            'media_type': 'mediaType'
        }

        self._external_contact_id = None
        self._conversation_id = None
        self._communication_id = None
        self._media_type = None

    @property
    def external_contact_id(self):
        """
        Gets the external_contact_id of this ConversationAssociation.
        An external contact ID.  If not supplied, implies the conversation should be disassociated with any external contact.

        :return: The external_contact_id of this ConversationAssociation.
        :rtype: str
        """
        return self._external_contact_id

    @external_contact_id.setter
    def external_contact_id(self, external_contact_id):
        """
        Sets the external_contact_id of this ConversationAssociation.
        An external contact ID.  If not supplied, implies the conversation should be disassociated with any external contact.

        :param external_contact_id: The external_contact_id of this ConversationAssociation.
        :type: str
        """
        
        self._external_contact_id = external_contact_id

    @property
    def conversation_id(self):
        """
        Gets the conversation_id of this ConversationAssociation.
        Conversation ID

        :return: The conversation_id of this ConversationAssociation.
        :rtype: str
        """
        return self._conversation_id

    @conversation_id.setter
    def conversation_id(self, conversation_id):
        """
        Sets the conversation_id of this ConversationAssociation.
        Conversation ID

        :param conversation_id: The conversation_id of this ConversationAssociation.
        :type: str
        """
        
        self._conversation_id = conversation_id

    @property
    def communication_id(self):
        """
        Gets the communication_id of this ConversationAssociation.
        Communication ID

        :return: The communication_id of this ConversationAssociation.
        :rtype: str
        """
        return self._communication_id

    @communication_id.setter
    def communication_id(self, communication_id):
        """
        Sets the communication_id of this ConversationAssociation.
        Communication ID

        :param communication_id: The communication_id of this ConversationAssociation.
        :type: str
        """
        
        self._communication_id = communication_id

    @property
    def media_type(self):
        """
        Gets the media_type of this ConversationAssociation.
        Media type

        :return: The media_type of this ConversationAssociation.
        :rtype: str
        """
        return self._media_type

    @media_type.setter
    def media_type(self, media_type):
        """
        Sets the media_type of this ConversationAssociation.
        Media type

        :param media_type: The media_type of this ConversationAssociation.
        :type: str
        """
        allowed_values = ["CALL", "CALLBACK", "CHAT", "COBROWSE", "EMAIL", "MESSAGE", "SOCIAL_EXPRESSION", "VIDEO", "SCREENSHARE"]
        if media_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for media_type -> " + media_type)
            self._media_type = "outdated_sdk_version"
        else:
            self._media_type = media_type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class SendAgentlessOutboundMessageResponse(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        SendAgentlessOutboundMessageResponse - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'conversation_id': 'str',
            'from_address': 'str',
            'to_address': 'str',
            'messenger_type': 'str',
            'text_body': 'str',
            'timestamp': 'datetime',
            'self_uri': 'str',
            'user': 'AddressableEntityRef'
        }

        self.attribute_map = {
            'id': 'id',
            'conversation_id': 'conversationId',
            'from_address': 'fromAddress',
            'to_address': 'toAddress',
            'messenger_type': 'messengerType',
            'text_body': 'textBody',
            'timestamp': 'timestamp',
            'self_uri': 'selfUri',
            'user': 'user'
        }

        self._id = None
        self._conversation_id = None
        self._from_address = None
        self._to_address = None
        self._messenger_type = None
        self._text_body = None
        self._timestamp = None
        self._self_uri = None
        self._user = None

    @property
    def id(self):
        """
        Gets the id of this SendAgentlessOutboundMessageResponse.
        The globally unique identifier for the object.

        :return: The id of this SendAgentlessOutboundMessageResponse.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this SendAgentlessOutboundMessageResponse.
        The globally unique identifier for the object.

        :param id: The id of this SendAgentlessOutboundMessageResponse.
        :type: str
        """
        
        self._id = id

    @property
    def conversation_id(self):
        """
        Gets the conversation_id of this SendAgentlessOutboundMessageResponse.
        The identifier of the conversation.

        :return: The conversation_id of this SendAgentlessOutboundMessageResponse.
        :rtype: str
        """
        return self._conversation_id

    @conversation_id.setter
    def conversation_id(self, conversation_id):
        """
        Sets the conversation_id of this SendAgentlessOutboundMessageResponse.
        The identifier of the conversation.

        :param conversation_id: The conversation_id of this SendAgentlessOutboundMessageResponse.
        :type: str
        """
        
        self._conversation_id = conversation_id

    @property
    def from_address(self):
        """
        Gets the from_address of this SendAgentlessOutboundMessageResponse.
        The sender of the text message.

        :return: The from_address of this SendAgentlessOutboundMessageResponse.
        :rtype: str
        """
        return self._from_address

    @from_address.setter
    def from_address(self, from_address):
        """
        Sets the from_address of this SendAgentlessOutboundMessageResponse.
        The sender of the text message.

        :param from_address: The from_address of this SendAgentlessOutboundMessageResponse.
        :type: str
        """
        
        self._from_address = from_address

    @property
    def to_address(self):
        """
        Gets the to_address of this SendAgentlessOutboundMessageResponse.
        The recipient of the text message.

        :return: The to_address of this SendAgentlessOutboundMessageResponse.
        :rtype: str
        """
        return self._to_address

    @to_address.setter
    def to_address(self, to_address):
        """
        Sets the to_address of this SendAgentlessOutboundMessageResponse.
        The recipient of the text message.

        :param to_address: The to_address of this SendAgentlessOutboundMessageResponse.
        :type: str
        """
        
        self._to_address = to_address

    @property
    def messenger_type(self):
        """
        Gets the messenger_type of this SendAgentlessOutboundMessageResponse.
        Type of text messenger.

        :return: The messenger_type of this SendAgentlessOutboundMessageResponse.
        :rtype: str
        """
        return self._messenger_type

    @messenger_type.setter
    def messenger_type(self, messenger_type):
        """
        Sets the messenger_type of this SendAgentlessOutboundMessageResponse.
        Type of text messenger.

        :param messenger_type: The messenger_type of this SendAgentlessOutboundMessageResponse.
        :type: str
        """
        allowed_values = ["sms", "facebook", "twitter", "line", "whatsapp", "webmessaging", "open"]
        if messenger_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for messenger_type -> " + messenger_type)
            self._messenger_type = "outdated_sdk_version"
        else:
            self._messenger_type = messenger_type

    @property
    def text_body(self):
        """
        Gets the text_body of this SendAgentlessOutboundMessageResponse.
        The body of the text message.

        :return: The text_body of this SendAgentlessOutboundMessageResponse.
        :rtype: str
        """
        return self._text_body

    @text_body.setter
    def text_body(self, text_body):
        """
        Sets the text_body of this SendAgentlessOutboundMessageResponse.
        The body of the text message.

        :param text_body: The text_body of this SendAgentlessOutboundMessageResponse.
        :type: str
        """
        
        self._text_body = text_body

    @property
    def timestamp(self):
        """
        Gets the timestamp of this SendAgentlessOutboundMessageResponse.
        The time when the message was sent. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The timestamp of this SendAgentlessOutboundMessageResponse.
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """
        Sets the timestamp of this SendAgentlessOutboundMessageResponse.
        The time when the message was sent. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param timestamp: The timestamp of this SendAgentlessOutboundMessageResponse.
        :type: datetime
        """
        
        self._timestamp = timestamp

    @property
    def self_uri(self):
        """
        Gets the self_uri of this SendAgentlessOutboundMessageResponse.
        The URI for this object

        :return: The self_uri of this SendAgentlessOutboundMessageResponse.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this SendAgentlessOutboundMessageResponse.
        The URI for this object

        :param self_uri: The self_uri of this SendAgentlessOutboundMessageResponse.
        :type: str
        """
        
        self._self_uri = self_uri

    @property
    def user(self):
        """
        Gets the user of this SendAgentlessOutboundMessageResponse.
        Details of the user created the job

        :return: The user of this SendAgentlessOutboundMessageResponse.
        :rtype: AddressableEntityRef
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this SendAgentlessOutboundMessageResponse.
        Details of the user created the job

        :param user: The user of this SendAgentlessOutboundMessageResponse.
        :type: AddressableEntityRef
        """
        
        self._user = user

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class CoachingAppointmentResponse(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        CoachingAppointmentResponse - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'date_start': 'datetime',
            'length_in_minutes': 'int',
            'status': 'str',
            'facilitator': 'UserReference',
            'attendees': 'list[UserReference]',
            'created_by': 'UserReference',
            'date_created': 'datetime',
            'modified_by': 'UserReference',
            'date_modified': 'datetime',
            'conversations': 'list[ConversationReference]',
            'documents': 'list[DocumentReference]',
            'is_overdue': 'bool',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'date_start': 'dateStart',
            'length_in_minutes': 'lengthInMinutes',
            'status': 'status',
            'facilitator': 'facilitator',
            'attendees': 'attendees',
            'created_by': 'createdBy',
            'date_created': 'dateCreated',
            'modified_by': 'modifiedBy',
            'date_modified': 'dateModified',
            'conversations': 'conversations',
            'documents': 'documents',
            'is_overdue': 'isOverdue',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._description = None
        self._date_start = None
        self._length_in_minutes = None
        self._status = None
        self._facilitator = None
        self._attendees = None
        self._created_by = None
        self._date_created = None
        self._modified_by = None
        self._date_modified = None
        self._conversations = None
        self._documents = None
        self._is_overdue = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this CoachingAppointmentResponse.
        The globally unique identifier for the object.

        :return: The id of this CoachingAppointmentResponse.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this CoachingAppointmentResponse.
        The globally unique identifier for the object.

        :param id: The id of this CoachingAppointmentResponse.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this CoachingAppointmentResponse.
        The name of coaching appointment

        :return: The name of this CoachingAppointmentResponse.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CoachingAppointmentResponse.
        The name of coaching appointment

        :param name: The name of this CoachingAppointmentResponse.
        :type: str
        """
        
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this CoachingAppointmentResponse.
        The description of coaching appointment

        :return: The description of this CoachingAppointmentResponse.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CoachingAppointmentResponse.
        The description of coaching appointment

        :param description: The description of this CoachingAppointmentResponse.
        :type: str
        """
        
        self._description = description

    @property
    def date_start(self):
        """
        Gets the date_start of this CoachingAppointmentResponse.
        The date/time the coaching appointment starts. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_start of this CoachingAppointmentResponse.
        :rtype: datetime
        """
        return self._date_start

    @date_start.setter
    def date_start(self, date_start):
        """
        Sets the date_start of this CoachingAppointmentResponse.
        The date/time the coaching appointment starts. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_start: The date_start of this CoachingAppointmentResponse.
        :type: datetime
        """
        
        self._date_start = date_start

    @property
    def length_in_minutes(self):
        """
        Gets the length_in_minutes of this CoachingAppointmentResponse.
        The duration of coaching appointment in minutes

        :return: The length_in_minutes of this CoachingAppointmentResponse.
        :rtype: int
        """
        return self._length_in_minutes

    @length_in_minutes.setter
    def length_in_minutes(self, length_in_minutes):
        """
        Sets the length_in_minutes of this CoachingAppointmentResponse.
        The duration of coaching appointment in minutes

        :param length_in_minutes: The length_in_minutes of this CoachingAppointmentResponse.
        :type: int
        """
        
        self._length_in_minutes = length_in_minutes

    @property
    def status(self):
        """
        Gets the status of this CoachingAppointmentResponse.
        The status of coaching appointment

        :return: The status of this CoachingAppointmentResponse.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this CoachingAppointmentResponse.
        The status of coaching appointment

        :param status: The status of this CoachingAppointmentResponse.
        :type: str
        """
        allowed_values = ["Scheduled", "InProgress", "Completed", "InvalidSchedule"]
        if status.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for status -> " + status)
            self._status = "outdated_sdk_version"
        else:
            self._status = status

    @property
    def facilitator(self):
        """
        Gets the facilitator of this CoachingAppointmentResponse.
        The facilitator of coaching appointment

        :return: The facilitator of this CoachingAppointmentResponse.
        :rtype: UserReference
        """
        return self._facilitator

    @facilitator.setter
    def facilitator(self, facilitator):
        """
        Sets the facilitator of this CoachingAppointmentResponse.
        The facilitator of coaching appointment

        :param facilitator: The facilitator of this CoachingAppointmentResponse.
        :type: UserReference
        """
        
        self._facilitator = facilitator

    @property
    def attendees(self):
        """
        Gets the attendees of this CoachingAppointmentResponse.
        The list of attendees attending the coaching

        :return: The attendees of this CoachingAppointmentResponse.
        :rtype: list[UserReference]
        """
        return self._attendees

    @attendees.setter
    def attendees(self, attendees):
        """
        Sets the attendees of this CoachingAppointmentResponse.
        The list of attendees attending the coaching

        :param attendees: The attendees of this CoachingAppointmentResponse.
        :type: list[UserReference]
        """
        
        self._attendees = attendees

    @property
    def created_by(self):
        """
        Gets the created_by of this CoachingAppointmentResponse.
        The user who created the coaching appointment

        :return: The created_by of this CoachingAppointmentResponse.
        :rtype: UserReference
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this CoachingAppointmentResponse.
        The user who created the coaching appointment

        :param created_by: The created_by of this CoachingAppointmentResponse.
        :type: UserReference
        """
        
        self._created_by = created_by

    @property
    def date_created(self):
        """
        Gets the date_created of this CoachingAppointmentResponse.
        The date/time the coaching appointment was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_created of this CoachingAppointmentResponse.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this CoachingAppointmentResponse.
        The date/time the coaching appointment was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_created: The date_created of this CoachingAppointmentResponse.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def modified_by(self):
        """
        Gets the modified_by of this CoachingAppointmentResponse.
        The last user to modify the coaching appointment

        :return: The modified_by of this CoachingAppointmentResponse.
        :rtype: UserReference
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """
        Sets the modified_by of this CoachingAppointmentResponse.
        The last user to modify the coaching appointment

        :param modified_by: The modified_by of this CoachingAppointmentResponse.
        :type: UserReference
        """
        
        self._modified_by = modified_by

    @property
    def date_modified(self):
        """
        Gets the date_modified of this CoachingAppointmentResponse.
        The date/time the coaching appointment was last modified. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_modified of this CoachingAppointmentResponse.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this CoachingAppointmentResponse.
        The date/time the coaching appointment was last modified. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_modified: The date_modified of this CoachingAppointmentResponse.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def conversations(self):
        """
        Gets the conversations of this CoachingAppointmentResponse.
        The list of conversations associated with coaching appointment.

        :return: The conversations of this CoachingAppointmentResponse.
        :rtype: list[ConversationReference]
        """
        return self._conversations

    @conversations.setter
    def conversations(self, conversations):
        """
        Sets the conversations of this CoachingAppointmentResponse.
        The list of conversations associated with coaching appointment.

        :param conversations: The conversations of this CoachingAppointmentResponse.
        :type: list[ConversationReference]
        """
        
        self._conversations = conversations

    @property
    def documents(self):
        """
        Gets the documents of this CoachingAppointmentResponse.
        The list of documents associated with coaching appointment.

        :return: The documents of this CoachingAppointmentResponse.
        :rtype: list[DocumentReference]
        """
        return self._documents

    @documents.setter
    def documents(self, documents):
        """
        Sets the documents of this CoachingAppointmentResponse.
        The list of documents associated with coaching appointment.

        :param documents: The documents of this CoachingAppointmentResponse.
        :type: list[DocumentReference]
        """
        
        self._documents = documents

    @property
    def is_overdue(self):
        """
        Gets the is_overdue of this CoachingAppointmentResponse.
        Whether the appointment is overdue.

        :return: The is_overdue of this CoachingAppointmentResponse.
        :rtype: bool
        """
        return self._is_overdue

    @is_overdue.setter
    def is_overdue(self, is_overdue):
        """
        Sets the is_overdue of this CoachingAppointmentResponse.
        Whether the appointment is overdue.

        :param is_overdue: The is_overdue of this CoachingAppointmentResponse.
        :type: bool
        """
        
        self._is_overdue = is_overdue

    @property
    def self_uri(self):
        """
        Gets the self_uri of this CoachingAppointmentResponse.
        The URI for this object

        :return: The self_uri of this CoachingAppointmentResponse.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this CoachingAppointmentResponse.
        The URI for this object

        :param self_uri: The self_uri of this CoachingAppointmentResponse.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class DevelopmentActivity(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DevelopmentActivity - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'date_completed': 'datetime',
            'created_by': 'UserReference',
            'date_created': 'datetime',
            'self_uri': 'str',
            'name': 'str',
            'type': 'str',
            'status': 'str',
            'date_due': 'datetime',
            'facilitator': 'UserReference',
            'attendees': 'list[UserReference]',
            'is_overdue': 'bool'
        }

        self.attribute_map = {
            'id': 'id',
            'date_completed': 'dateCompleted',
            'created_by': 'createdBy',
            'date_created': 'dateCreated',
            'self_uri': 'selfUri',
            'name': 'name',
            'type': 'type',
            'status': 'status',
            'date_due': 'dateDue',
            'facilitator': 'facilitator',
            'attendees': 'attendees',
            'is_overdue': 'isOverdue'
        }

        self._id = None
        self._date_completed = None
        self._created_by = None
        self._date_created = None
        self._self_uri = None
        self._name = None
        self._type = None
        self._status = None
        self._date_due = None
        self._facilitator = None
        self._attendees = None
        self._is_overdue = None

    @property
    def id(self):
        """
        Gets the id of this DevelopmentActivity.
        The globally unique identifier for the object.

        :return: The id of this DevelopmentActivity.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DevelopmentActivity.
        The globally unique identifier for the object.

        :param id: The id of this DevelopmentActivity.
        :type: str
        """
        
        self._id = id

    @property
    def date_completed(self):
        """
        Gets the date_completed of this DevelopmentActivity.
        Date that activity was completed. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_completed of this DevelopmentActivity.
        :rtype: datetime
        """
        return self._date_completed

    @date_completed.setter
    def date_completed(self, date_completed):
        """
        Sets the date_completed of this DevelopmentActivity.
        Date that activity was completed. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_completed: The date_completed of this DevelopmentActivity.
        :type: datetime
        """
        
        self._date_completed = date_completed

    @property
    def created_by(self):
        """
        Gets the created_by of this DevelopmentActivity.
        User that created activity

        :return: The created_by of this DevelopmentActivity.
        :rtype: UserReference
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this DevelopmentActivity.
        User that created activity

        :param created_by: The created_by of this DevelopmentActivity.
        :type: UserReference
        """
        
        self._created_by = created_by

    @property
    def date_created(self):
        """
        Gets the date_created of this DevelopmentActivity.
        Date activity was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_created of this DevelopmentActivity.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this DevelopmentActivity.
        Date activity was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_created: The date_created of this DevelopmentActivity.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def self_uri(self):
        """
        Gets the self_uri of this DevelopmentActivity.
        The URI for this object

        :return: The self_uri of this DevelopmentActivity.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this DevelopmentActivity.
        The URI for this object

        :param self_uri: The self_uri of this DevelopmentActivity.
        :type: str
        """
        
        self._self_uri = self_uri

    @property
    def name(self):
        """
        Gets the name of this DevelopmentActivity.
        The name of the activity

        :return: The name of this DevelopmentActivity.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DevelopmentActivity.
        The name of the activity

        :param name: The name of this DevelopmentActivity.
        :type: str
        """
        
        self._name = name

    @property
    def type(self):
        """
        Gets the type of this DevelopmentActivity.
        The type of activity

        :return: The type of this DevelopmentActivity.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this DevelopmentActivity.
        The type of activity

        :param type: The type of this DevelopmentActivity.
        :type: str
        """
        allowed_values = ["Informational", "Coaching"]
        if type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for type -> " + type)
            self._type = "outdated_sdk_version"
        else:
            self._type = type

    @property
    def status(self):
        """
        Gets the status of this DevelopmentActivity.
        The status of the activity

        :return: The status of this DevelopmentActivity.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this DevelopmentActivity.
        The status of the activity

        :param status: The status of this DevelopmentActivity.
        :type: str
        """
        allowed_values = ["Planned", "InProgress", "Completed", "InvalidSchedule"]
        if status.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for status -> " + status)
            self._status = "outdated_sdk_version"
        else:
            self._status = status

    @property
    def date_due(self):
        """
        Gets the date_due of this DevelopmentActivity.
        Due date for completion of the activity. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_due of this DevelopmentActivity.
        :rtype: datetime
        """
        return self._date_due

    @date_due.setter
    def date_due(self, date_due):
        """
        Sets the date_due of this DevelopmentActivity.
        Due date for completion of the activity. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_due: The date_due of this DevelopmentActivity.
        :type: datetime
        """
        
        self._date_due = date_due

    @property
    def facilitator(self):
        """
        Gets the facilitator of this DevelopmentActivity.
        Facilitator of the activity

        :return: The facilitator of this DevelopmentActivity.
        :rtype: UserReference
        """
        return self._facilitator

    @facilitator.setter
    def facilitator(self, facilitator):
        """
        Sets the facilitator of this DevelopmentActivity.
        Facilitator of the activity

        :param facilitator: The facilitator of this DevelopmentActivity.
        :type: UserReference
        """
        
        self._facilitator = facilitator

    @property
    def attendees(self):
        """
        Gets the attendees of this DevelopmentActivity.
        List of users attending the activity

        :return: The attendees of this DevelopmentActivity.
        :rtype: list[UserReference]
        """
        return self._attendees

    @attendees.setter
    def attendees(self, attendees):
        """
        Sets the attendees of this DevelopmentActivity.
        List of users attending the activity

        :param attendees: The attendees of this DevelopmentActivity.
        :type: list[UserReference]
        """
        
        self._attendees = attendees

    @property
    def is_overdue(self):
        """
        Gets the is_overdue of this DevelopmentActivity.
        Indicates if the activity is overdue

        :return: The is_overdue of this DevelopmentActivity.
        :rtype: bool
        """
        return self._is_overdue

    @is_overdue.setter
    def is_overdue(self, is_overdue):
        """
        Sets the is_overdue of this DevelopmentActivity.
        Indicates if the activity is overdue

        :param is_overdue: The is_overdue of this DevelopmentActivity.
        :type: bool
        """
        
        self._is_overdue = is_overdue

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class VoicemailGroupPolicy(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        VoicemailGroupPolicy - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'name': 'str',
            'group': 'Group',
            'enabled': 'bool',
            'send_email_notifications': 'bool',
            'rotate_calls_secs': 'int',
            'stop_ringing_after_rotations': 'int',
            'overflow_group_id': 'str',
            'group_alert_type': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'group': 'group',
            'enabled': 'enabled',
            'send_email_notifications': 'sendEmailNotifications',
            'rotate_calls_secs': 'rotateCallsSecs',
            'stop_ringing_after_rotations': 'stopRingingAfterRotations',
            'overflow_group_id': 'overflowGroupId',
            'group_alert_type': 'groupAlertType'
        }

        self._name = None
        self._group = None
        self._enabled = None
        self._send_email_notifications = None
        self._rotate_calls_secs = None
        self._stop_ringing_after_rotations = None
        self._overflow_group_id = None
        self._group_alert_type = None

    @property
    def name(self):
        """
        Gets the name of this VoicemailGroupPolicy.


        :return: The name of this VoicemailGroupPolicy.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this VoicemailGroupPolicy.


        :param name: The name of this VoicemailGroupPolicy.
        :type: str
        """
        
        self._name = name

    @property
    def group(self):
        """
        Gets the group of this VoicemailGroupPolicy.
        The group associated with the policy

        :return: The group of this VoicemailGroupPolicy.
        :rtype: Group
        """
        return self._group

    @group.setter
    def group(self, group):
        """
        Sets the group of this VoicemailGroupPolicy.
        The group associated with the policy

        :param group: The group of this VoicemailGroupPolicy.
        :type: Group
        """
        
        self._group = group

    @property
    def enabled(self):
        """
        Gets the enabled of this VoicemailGroupPolicy.
        Whether voicemail is enabled for the group

        :return: The enabled of this VoicemailGroupPolicy.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this VoicemailGroupPolicy.
        Whether voicemail is enabled for the group

        :param enabled: The enabled of this VoicemailGroupPolicy.
        :type: bool
        """
        
        self._enabled = enabled

    @property
    def send_email_notifications(self):
        """
        Gets the send_email_notifications of this VoicemailGroupPolicy.
        Whether email notifications are sent to group members when a new voicemail is received

        :return: The send_email_notifications of this VoicemailGroupPolicy.
        :rtype: bool
        """
        return self._send_email_notifications

    @send_email_notifications.setter
    def send_email_notifications(self, send_email_notifications):
        """
        Sets the send_email_notifications of this VoicemailGroupPolicy.
        Whether email notifications are sent to group members when a new voicemail is received

        :param send_email_notifications: The send_email_notifications of this VoicemailGroupPolicy.
        :type: bool
        """
        
        self._send_email_notifications = send_email_notifications

    @property
    def rotate_calls_secs(self):
        """
        Gets the rotate_calls_secs of this VoicemailGroupPolicy.
        How many seconds to ring before rotating to the next member in the group

        :return: The rotate_calls_secs of this VoicemailGroupPolicy.
        :rtype: int
        """
        return self._rotate_calls_secs

    @rotate_calls_secs.setter
    def rotate_calls_secs(self, rotate_calls_secs):
        """
        Sets the rotate_calls_secs of this VoicemailGroupPolicy.
        How many seconds to ring before rotating to the next member in the group

        :param rotate_calls_secs: The rotate_calls_secs of this VoicemailGroupPolicy.
        :type: int
        """
        
        self._rotate_calls_secs = rotate_calls_secs

    @property
    def stop_ringing_after_rotations(self):
        """
        Gets the stop_ringing_after_rotations of this VoicemailGroupPolicy.
        How many rotations to go through

        :return: The stop_ringing_after_rotations of this VoicemailGroupPolicy.
        :rtype: int
        """
        return self._stop_ringing_after_rotations

    @stop_ringing_after_rotations.setter
    def stop_ringing_after_rotations(self, stop_ringing_after_rotations):
        """
        Sets the stop_ringing_after_rotations of this VoicemailGroupPolicy.
        How many rotations to go through

        :param stop_ringing_after_rotations: The stop_ringing_after_rotations of this VoicemailGroupPolicy.
        :type: int
        """
        
        self._stop_ringing_after_rotations = stop_ringing_after_rotations

    @property
    def overflow_group_id(self):
        """
        Gets the overflow_group_id of this VoicemailGroupPolicy.
         A fallback group to contact when all of the members in this group did not answer the call.

        :return: The overflow_group_id of this VoicemailGroupPolicy.
        :rtype: str
        """
        return self._overflow_group_id

    @overflow_group_id.setter
    def overflow_group_id(self, overflow_group_id):
        """
        Sets the overflow_group_id of this VoicemailGroupPolicy.
         A fallback group to contact when all of the members in this group did not answer the call.

        :param overflow_group_id: The overflow_group_id of this VoicemailGroupPolicy.
        :type: str
        """
        
        self._overflow_group_id = overflow_group_id

    @property
    def group_alert_type(self):
        """
        Gets the group_alert_type of this VoicemailGroupPolicy.
        Specifies if the members in this group should be contacted randomly, in a specific order, or by round-robin.

        :return: The group_alert_type of this VoicemailGroupPolicy.
        :rtype: str
        """
        return self._group_alert_type

    @group_alert_type.setter
    def group_alert_type(self, group_alert_type):
        """
        Sets the group_alert_type of this VoicemailGroupPolicy.
        Specifies if the members in this group should be contacted randomly, in a specific order, or by round-robin.

        :param group_alert_type: The group_alert_type of this VoicemailGroupPolicy.
        :type: str
        """
        allowed_values = ["RANDOM", "ROUND_ROBIN", "SEQUENTIAL"]
        if group_alert_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for group_alert_type -> " + group_alert_type)
            self._group_alert_type = "outdated_sdk_version"
        else:
            self._group_alert_type = group_alert_type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class AnalyticsConversation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        AnalyticsConversation - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'conversation_id': 'str',
            'conversation_start': 'datetime',
            'conversation_end': 'datetime',
            'media_stats_min_conversation_mos': 'float',
            'media_stats_min_conversation_r_factor': 'float',
            'originating_direction': 'str',
            'evaluations': 'list[AnalyticsEvaluation]',
            'surveys': 'list[AnalyticsSurvey]',
            'resolutions': 'list[AnalyticsResolution]',
            'division_ids': 'list[str]',
            'participants': 'list[AnalyticsParticipant]'
        }

        self.attribute_map = {
            'conversation_id': 'conversationId',
            'conversation_start': 'conversationStart',
            'conversation_end': 'conversationEnd',
            'media_stats_min_conversation_mos': 'mediaStatsMinConversationMos',
            'media_stats_min_conversation_r_factor': 'mediaStatsMinConversationRFactor',
            'originating_direction': 'originatingDirection',
            'evaluations': 'evaluations',
            'surveys': 'surveys',
            'resolutions': 'resolutions',
            'division_ids': 'divisionIds',
            'participants': 'participants'
        }

        self._conversation_id = None
        self._conversation_start = None
        self._conversation_end = None
        self._media_stats_min_conversation_mos = None
        self._media_stats_min_conversation_r_factor = None
        self._originating_direction = None
        self._evaluations = None
        self._surveys = None
        self._resolutions = None
        self._division_ids = None
        self._participants = None

    @property
    def conversation_id(self):
        """
        Gets the conversation_id of this AnalyticsConversation.
        Unique identifier for the conversation

        :return: The conversation_id of this AnalyticsConversation.
        :rtype: str
        """
        return self._conversation_id

    @conversation_id.setter
    def conversation_id(self, conversation_id):
        """
        Sets the conversation_id of this AnalyticsConversation.
        Unique identifier for the conversation

        :param conversation_id: The conversation_id of this AnalyticsConversation.
        :type: str
        """
        
        self._conversation_id = conversation_id

    @property
    def conversation_start(self):
        """
        Gets the conversation_start of this AnalyticsConversation.
        Date/time the conversation started. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The conversation_start of this AnalyticsConversation.
        :rtype: datetime
        """
        return self._conversation_start

    @conversation_start.setter
    def conversation_start(self, conversation_start):
        """
        Sets the conversation_start of this AnalyticsConversation.
        Date/time the conversation started. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param conversation_start: The conversation_start of this AnalyticsConversation.
        :type: datetime
        """
        
        self._conversation_start = conversation_start

    @property
    def conversation_end(self):
        """
        Gets the conversation_end of this AnalyticsConversation.
        Date/time the conversation ended. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The conversation_end of this AnalyticsConversation.
        :rtype: datetime
        """
        return self._conversation_end

    @conversation_end.setter
    def conversation_end(self, conversation_end):
        """
        Sets the conversation_end of this AnalyticsConversation.
        Date/time the conversation ended. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param conversation_end: The conversation_end of this AnalyticsConversation.
        :type: datetime
        """
        
        self._conversation_end = conversation_end

    @property
    def media_stats_min_conversation_mos(self):
        """
        Gets the media_stats_min_conversation_mos of this AnalyticsConversation.
        The lowest estimated average MOS among all the audio streams belonging to this conversation

        :return: The media_stats_min_conversation_mos of this AnalyticsConversation.
        :rtype: float
        """
        return self._media_stats_min_conversation_mos

    @media_stats_min_conversation_mos.setter
    def media_stats_min_conversation_mos(self, media_stats_min_conversation_mos):
        """
        Sets the media_stats_min_conversation_mos of this AnalyticsConversation.
        The lowest estimated average MOS among all the audio streams belonging to this conversation

        :param media_stats_min_conversation_mos: The media_stats_min_conversation_mos of this AnalyticsConversation.
        :type: float
        """
        
        self._media_stats_min_conversation_mos = media_stats_min_conversation_mos

    @property
    def media_stats_min_conversation_r_factor(self):
        """
        Gets the media_stats_min_conversation_r_factor of this AnalyticsConversation.
        The lowest R-factor value among all of the audio streams belonging to this conversation

        :return: The media_stats_min_conversation_r_factor of this AnalyticsConversation.
        :rtype: float
        """
        return self._media_stats_min_conversation_r_factor

    @media_stats_min_conversation_r_factor.setter
    def media_stats_min_conversation_r_factor(self, media_stats_min_conversation_r_factor):
        """
        Sets the media_stats_min_conversation_r_factor of this AnalyticsConversation.
        The lowest R-factor value among all of the audio streams belonging to this conversation

        :param media_stats_min_conversation_r_factor: The media_stats_min_conversation_r_factor of this AnalyticsConversation.
        :type: float
        """
        
        self._media_stats_min_conversation_r_factor = media_stats_min_conversation_r_factor

    @property
    def originating_direction(self):
        """
        Gets the originating_direction of this AnalyticsConversation.
        The original direction of the conversation

        :return: The originating_direction of this AnalyticsConversation.
        :rtype: str
        """
        return self._originating_direction

    @originating_direction.setter
    def originating_direction(self, originating_direction):
        """
        Sets the originating_direction of this AnalyticsConversation.
        The original direction of the conversation

        :param originating_direction: The originating_direction of this AnalyticsConversation.
        :type: str
        """
        allowed_values = ["inbound", "outbound"]
        if originating_direction.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for originating_direction -> " + originating_direction)
            self._originating_direction = "outdated_sdk_version"
        else:
            self._originating_direction = originating_direction

    @property
    def evaluations(self):
        """
        Gets the evaluations of this AnalyticsConversation.
        Evaluations tied to this conversation

        :return: The evaluations of this AnalyticsConversation.
        :rtype: list[AnalyticsEvaluation]
        """
        return self._evaluations

    @evaluations.setter
    def evaluations(self, evaluations):
        """
        Sets the evaluations of this AnalyticsConversation.
        Evaluations tied to this conversation

        :param evaluations: The evaluations of this AnalyticsConversation.
        :type: list[AnalyticsEvaluation]
        """
        
        self._evaluations = evaluations

    @property
    def surveys(self):
        """
        Gets the surveys of this AnalyticsConversation.
        Surveys tied to this conversation

        :return: The surveys of this AnalyticsConversation.
        :rtype: list[AnalyticsSurvey]
        """
        return self._surveys

    @surveys.setter
    def surveys(self, surveys):
        """
        Sets the surveys of this AnalyticsConversation.
        Surveys tied to this conversation

        :param surveys: The surveys of this AnalyticsConversation.
        :type: list[AnalyticsSurvey]
        """
        
        self._surveys = surveys

    @property
    def resolutions(self):
        """
        Gets the resolutions of this AnalyticsConversation.
        Resolutions tied to this conversation

        :return: The resolutions of this AnalyticsConversation.
        :rtype: list[AnalyticsResolution]
        """
        return self._resolutions

    @resolutions.setter
    def resolutions(self, resolutions):
        """
        Sets the resolutions of this AnalyticsConversation.
        Resolutions tied to this conversation

        :param resolutions: The resolutions of this AnalyticsConversation.
        :type: list[AnalyticsResolution]
        """
        
        self._resolutions = resolutions

    @property
    def division_ids(self):
        """
        Gets the division_ids of this AnalyticsConversation.
        Identifiers of divisions associated with this conversation

        :return: The division_ids of this AnalyticsConversation.
        :rtype: list[str]
        """
        return self._division_ids

    @division_ids.setter
    def division_ids(self, division_ids):
        """
        Sets the division_ids of this AnalyticsConversation.
        Identifiers of divisions associated with this conversation

        :param division_ids: The division_ids of this AnalyticsConversation.
        :type: list[str]
        """
        
        self._division_ids = division_ids

    @property
    def participants(self):
        """
        Gets the participants of this AnalyticsConversation.
        Participants in the conversation

        :return: The participants of this AnalyticsConversation.
        :rtype: list[AnalyticsParticipant]
        """
        return self._participants

    @participants.setter
    def participants(self, participants):
        """
        Sets the participants of this AnalyticsConversation.
        Participants in the conversation

        :param participants: The participants of this AnalyticsConversation.
        :type: list[AnalyticsParticipant]
        """
        
        self._participants = participants

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

